{% load i18n %}
<div class="path-input-container" data-path-widget>
  <div class="path-mode-file" data-path-mode="file">
    {% with widget=widget.subwidgets.0 %}
      {% include widget.template_name %}
    {% endwith %}
    <a href="#" class="path-mode-toggle" data-toggle-to="text">{% trans "or enter path as text" %}</a>
  </div>
  <div class="path-mode-text" data-path-mode="text" style="display:none">
    {% with widget=widget.subwidgets.1 %}
      {% include widget.template_name %}
    {% endwith %}
    <a href="#" class="path-mode-toggle" data-toggle-to="file">{% trans "or upload a file" %}</a>
  </div>
</div>
